Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1114)

Unified Diff: content/browser/browser_main_loop.cc

Issue 1547793004: Make gpu black list work again on Linux (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove changes from gpu_info_collector files Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/browser_main_loop.cc
diff --git a/content/browser/browser_main_loop.cc b/content/browser/browser_main_loop.cc
index 012926b888cc38a5942ad2c5c57cba10f8ae1fd7..b947969b99f0158bb23782f3c0cad0a811ded665 100644
--- a/content/browser/browser_main_loop.cc
+++ b/content/browser/browser_main_loop.cc
@@ -707,7 +707,7 @@ int BrowserMainLoop::PreCreateThreads() {
"BrowserMainLoop::CreateThreads:PreCreateThreads");
TRACK_SCOPED_REGION("Startup", "BrowserMainLoop::PreCreateThreads");
- result_code_ = parts_->PreCreateThreads();
+ result_code_ = parts_->PreCreateThreadsBegin();
}
// Initialize an instance of FeatureList. This will be a no-op if an instance
@@ -749,7 +749,7 @@ int BrowserMainLoop::PreCreateThreads() {
// 1) Need to initialize in-process GpuDataManager before creating threads.
// It's unsafe to append the gpu command line switches to the global
// CommandLine::ForCurrentProcess object after threads are created.
// 2) Must be after parts_->PreCreateThreads to pick up chrome://flags.
GpuDataManagerImpl::GetInstance()->Initialize();
#if !defined(OS_IOS) && (!defined(GOOGLE_CHROME_BUILD) || defined(OS_ANDROID))
@@ -759,6 +759,11 @@ int BrowserMainLoop::PreCreateThreads() {
RenderProcessHost::SetRunRendererInProcess(true);
#endif
+ // parts may want to do some processing just before actually starting the
+ // threads.
+ if (parts_)
+ parts_->PreCreateThreadsEnd();
+
return result_code_;
}
@@ -749,7 +749,7 @@ int BrowserMainLoop::PreCreateThreads() {
// It's unsafe to append the gpu command line switches to the global
// CommandLine::ForCurrentProcess object after threads are created.
- // 2) Must be after parts_->PreCreateThreads to pick up chrome://flags.
+ // 2) Must be after parts_->PreCreateThreadsBegin to pick up chrome://flags.
GpuDataManagerImpl::GetInstance()->Initialize();
#if !defined(OS_IOS) && (!defined(GOOGLE_CHROME_BUILD) || defined(OS_ANDROID))

Powered by Google App Engine
This is Rietveld 408576698